@@ -34,7 +34,7 @@ from urllib.error import HTTPError
 from urllib.parse import urlparse
 from urllib.request import Request, urlopen
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 __all__ = ["Configuration", "FHIRSpec", "download", "filename_from_response"]
 
@@ -2070,6 +2070,8 @@ class FHIRUnitTest:
                     if list == type(val):
                         i = 0
                         for ival in val:
+                            if ival is None:
+                                continue
                             idxpath = self.controller.settings.UNITTEST_FORMAT_PATH_INDEX.format(  # noqa: E501
                                 path, i
                             )
@@ -2081,6 +2083,8 @@ class FHIRUnitTest:
                             if i >= 10:  # let's assume we don't need 100s of unit tests
                                 break
                     else:
+                        if val is None:
+                            continue
                         item = FHIRUnitTestItem(
                             self.filepath, path, val, propclass, False, prop.enum
                         )
